/*
 * Name:    d_icplus_aio.h
 *
 * Purpose: Header file for MX analog input and output drivers to control the
 *          Oxford Danfysik IC PLUS high voltage and read the input current.
 *
 *          The analog output driver 'icplus_voltage' controls the high
 *          voltage setting, while the analog input driver 'icplus_current'
 *          returns the ion chamber current.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __D_ICPLUS_AIO_H__
#define __D_ICPLUS_AIO_H__

#include "mx_analog_input.h"
#include "mx_analog_output.h"

/* ===== IC PLUS analog input/output data structures ===== */

typedef struct {
	MX_RECORD *record;

	MX_RECORD *icplus_record;
} MX_ICPLUS_AINPUT;

typedef struct {
	MX_RECORD *record;

	MX_RECORD *icplus_record;
} MX_ICPLUS_AOUTPUT;

#define MXD_ICPLUS_AINPUT_STANDARD_FIELDS \
  {-1, -1, "icplus_record", MXFT_RECORD, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_ICPLUS_AINPUT, icplus_record), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

#define MXD_ICPLUS_AOUTPUT_STANDARD_FIELDS \
  {-1, -1, "icplus_record", MXFT_RECORD, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_ICPLUS_AOUTPUT, icplus_record), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

/* Define all of the interface functions. */

/* First the functions to read the ion chamber current. */

MX_API mx_status_type mxd_icplus_ain_create_record_structures(
							MX_RECORD *record );
MX_API mx_status_type mxd_icplus_ain_read( MX_ANALOG_INPUT *dinput );

extern MX_RECORD_FUNCTION_LIST mxd_icplus_ain_record_function_list;
extern MX_ANALOG_INPUT_FUNCTION_LIST
				mxd_icplus_ain_analog_input_function_list;

extern long mxd_icplus_ain_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_icplus_ain_rfield_def_ptr;

/* Second the functions to set the high voltage. */

MX_API mx_status_type mxd_icplus_aout_create_record_structures(
							MX_RECORD *record );
MX_API mx_status_type mxd_icplus_aout_read( MX_ANALOG_OUTPUT *doutput );
MX_API mx_status_type mxd_icplus_aout_write( MX_ANALOG_OUTPUT *doutput );

extern MX_RECORD_FUNCTION_LIST mxd_icplus_aout_record_function_list;
extern MX_ANALOG_OUTPUT_FUNCTION_LIST
				mxd_icplus_aout_analog_output_function_list;

extern long mxd_icplus_aout_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_icplus_aout_rfield_def_ptr;

#endif /* __D_ICPLUS_AIO_H__ */

