/*
 * Name:    d_remote_marccd.h
 *
 * Purpose: MX driver header for MarCCD when run in 
 *          "Remote" data collection mode.
 *
 * Author:  William Lavender
 *
 *--------------------------------------------------------------------------
 *
 * Copyright 2003 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __D_REMOTE_MARCCD_H__
#define __D_REMOTE_MARCCD_H__

typedef struct {
	MX_RECORD *record;

	FILE *from_marccd;
	FILE *to_marccd;

	/* File descriptors used if the current process was started directly
	 * by MarCCD.
	 */

	int fd_from_marccd;
	int fd_to_marccd;

	/* Socket used if the current process has to connect to a remote host
	 * running 'marccd_server_socket' or some such replacement.
	 */

	MX_SOCKET marccd_socket;

	char marccd_host[ MXU_HOSTNAME_LENGTH + 1 ];
	int marccd_port;
} MX_REMOTE_MARCCD;


#define MXD_REMOTE_MARCCD_STANDARD_FIELDS \
  {-1, -1, "marccd_host", MXFT_STRING, NULL, 1, {MXU_HOSTNAME_LENGTH + 1}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_REMOTE_MARCCD, marccd_host), \
	{sizeof(char)}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "marccd_port", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_REMOTE_MARCCD, marccd_port), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}

MX_API mx_status_type mxd_remote_marccd_create_record_structures(
					MX_RECORD *record );
MX_API mx_status_type mxd_remote_marccd_open( MX_RECORD *record );
MX_API mx_status_type mxd_remote_marccd_close( MX_RECORD *record );

MX_API mx_status_type mxd_remote_marccd_start( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_stop( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_get_status( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_readout( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_dezinger( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_correct( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_writefile( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_get_parameter( MX_CCD *ccd );
MX_API mx_status_type mxd_remote_marccd_set_parameter( MX_CCD *ccd );

MX_API mx_status_type mxd_remote_marccd_command(
				MX_REMOTE_MARCCD *remote_marccd, char *command,
				char *response, size_t response_length,
				int flags );

extern MX_RECORD_FUNCTION_LIST mxd_remote_marccd_record_function_list;
extern MX_CCD_FUNCTION_LIST mxd_remote_marccd_ccd_function_list;

extern long mxd_remote_marccd_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_remote_marccd_rfield_def_ptr;

#endif /* __D_REMOTE_MARCCD_H__ */

