/* 
 * Name:    d_xia_dxp_mca.h
 *
 * Purpose: Header file for the X-Ray Instrumentation Associates Mesa2x
 *          Data Server used by the DXP-2X multichannel analyzer.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 2001-2003 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __D_XIA_DXP_MCA_H__
#define __D_XIA_DXP_MCA_H__

#include "mx_mca.h"

#define MX_XIA_DXP_CLOCK_TICK		(400.0e-9)	/* in seconds */

#define MXU_XIA_DXP_PARAMETER_NAME_LENGTH	80

/* The following defines are used by the 'statistics' record field. */

#define MX_XIA_DXP_NUM_STATISTICS	8

#define MX_XIA_DXP_REAL_TIME		0
#define MX_XIA_DXP_LIVE_TIME		1
#define MX_XIA_DXP_INPUT_COUNT_RATE	2
#define MX_XIA_DXP_OUTPUT_COUNT_RATE	3
#define MX_XIA_DXP_NUM_FAST_PEAKS	4
#define MX_XIA_DXP_NUM_EVENTS		5
#define MX_XIA_DXP_NUM_UNDERFLOWS	6
#define MX_XIA_DXP_NUM_OVERFLOWS	7

/* The following flags are used by the "PRESET" MCA parameter. */

#define MXF_XIA_PRESET_NONE		0
#define MXF_XIA_PRESET_REAL_TIME	1
#define MXF_XIA_PRESET_LIVE_TIME	2
#define MXF_XIA_PRESET_OUTPUT_EVENTS	3
#define MXF_XIA_PRESET_INPUT_COUNTS	4

typedef struct {
	MX_RECORD *record;

	MX_RECORD *xia_dxp_record;
	char mca_label[MXU_RECORD_NAME_LENGTH + 1];

	double statistics[ MX_XIA_DXP_NUM_STATISTICS ];
	char parameter_name[ MXU_XIA_DXP_PARAMETER_NAME_LENGTH + 1 ];
	unsigned long parameter_value;
	unsigned long param_value_to_all_channels;

	int system_channel;

	int dxp_module;

	int crate;
	int slot;
	int dxp_channel;

	int new_statistics_available;

	double clock_tick;	/* In seconds.  Either 400.0e-9 or 800.0e-9. */

	double input_count_rate;
	double output_count_rate;

	mx_uint32_type num_fast_peaks;
	mx_uint32_type num_events;
	mx_uint32_type num_underflows;
	mx_uint32_type num_overflows;

	mx_uint32_type old_preset_type;
	mx_uint32_type old_preset_high_order;
	mx_uint32_type old_preset_low_order;

	mx_status_type (*is_busy)( MX_MCA *mca,
					int *busy_flag,
					int debug_flag);

	mx_status_type (*read_parameter)( MX_MCA *mca,
					char *parameter_name,
					mx_uint32_type *value_ptr,
					int debug_flag );

	mx_status_type (*write_parameter)( MX_MCA *mca,
					char *parameter_name,
					mx_uint32_type value,
					int debug_flag );

	mx_status_type (*write_parameter_to_all_channels)( MX_MCA *mca,
					char *parameter_name,
					mx_uint32_type value,
					int debug_flag );

	mx_status_type (*start_run)( MX_MCA *mca,
					int clear_flag,
					int debug_flag );

	mx_status_type (*stop_run)( MX_MCA *mca,
					int debug_flag );

	mx_status_type (*read_spectrum)( MX_MCA *mca,
					int debug_flag );

	mx_status_type (*read_statistics)( MX_MCA *mca,
					int debug_flag );

#if HAVE_XIA_HANDEL

	unsigned short num_parameters;
	unsigned short *parameter_array;

	unsigned int num_baseline_bins;
	unsigned short *baseline_array;
	
	int use_mca_channel_array;

	unsigned int num_spectrum_bins;
	unsigned long *spectrum_array;

#endif /* HAVE_XIA_HANDEL */

} MX_XIA_DXP_MCA;


#define MXLV_XIA_DXP_STATISTICS				2001
#define MXLV_XIA_DXP_PARAMETER_NAME			2002
#define MXLV_XIA_DXP_PARAMETER_VALUE			2003
#define MXLV_XIA_DXP_PARAM_VALUE_TO_ALL_CHANNELS	2004


#define MXD_XIA_DXP_STANDARD_FIELDS \
  {-1, -1, "xia_dxp_record", MXFT_RECORD, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof( MX_XIA_DXP_MCA, xia_dxp_record ), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "mca_label", MXFT_STRING, NULL, 1, {MXU_RECORD_NAME_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof( MX_XIA_DXP_MCA, mca_label ), \
	{sizeof(char)}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {MXLV_XIA_DXP_STATISTICS, -1, "statistics", \
			MXFT_DOUBLE, NULL, 1, {MX_XIA_DXP_NUM_STATISTICS}, \
	MXF_REC_TYPE_STRUCT, offsetof( MX_XIA_DXP_MCA, statistics ), \
	{sizeof(double)}, NULL, 0}, \
  \
  {MXLV_XIA_DXP_PARAMETER_NAME, -1, "parameter_name", \
		MXFT_STRING, NULL, 1, {MXU_XIA_DXP_PARAMETER_NAME_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof( MX_XIA_DXP_MCA, parameter_name ), \
	{sizeof(char)}, NULL, 0}, \
  \
  {MXLV_XIA_DXP_PARAMETER_VALUE, -1, "parameter_value", \
			MXFT_ULONG, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof( MX_XIA_DXP_MCA, parameter_value ), \
	{0}, NULL, 0}, \
  \
  {MXLV_XIA_DXP_PARAM_VALUE_TO_ALL_CHANNELS, -1, \
			"param_value_to_all_channels", \
			MXFT_ULONG, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof( MX_XIA_DXP_MCA, \
			param_value_to_all_channels ), \
	{0}, NULL, 0}

MX_API mx_status_type mxd_xia_dxp_initialize_type( long type );
MX_API mx_status_type mxd_xia_dxp_create_record_structures( MX_RECORD *record );
MX_API mx_status_type mxd_xia_dxp_finish_record_initialization(
							MX_RECORD *record );
MX_API mx_status_type mxd_xia_dxp_delete_record( MX_RECORD *record );
MX_API mx_status_type mxd_xia_dxp_print_structure( FILE *file,
							MX_RECORD *record );
MX_API mx_status_type mxd_xia_dxp_open( MX_RECORD *record );
MX_API mx_status_type mxd_xia_dxp_close( MX_RECORD *record );
MX_API mx_status_type mxd_xia_dxp_special_processing_setup( MX_RECORD *record );

MX_API mx_status_type mxd_xia_dxp_start( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_stop( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_read( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_clear( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_busy( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_get_parameter( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_set_parameter( MX_MCA *mca );

MX_API mx_status_type mxd_xia_dxp_get_local_parameter( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_set_local_parameter( MX_MCA *mca );

MX_API mx_status_type mxd_xia_dxp_get_network_parameter( MX_MCA *mca );
MX_API mx_status_type mxd_xia_dxp_set_network_parameter( MX_MCA *mca );

MX_API mx_status_type mxd_xia_dxp_get_mca_array( MX_RECORD *xia_dxp_record,
					unsigned long *num_mcas,
					MX_RECORD ***mca_record_array );

MX_API mx_status_type mxd_xia_dxp_get_corrected_roi( MX_MCA *mca,
					unsigned long roi_number,
					double *corrected_roi_value );

MX_API mx_status_type mxd_xia_dxp_read_statistics( MX_MCA *mca,
						MX_XIA_DXP_MCA *xia_dxp_mca,
						int debug_flag );

extern MX_RECORD_FUNCTION_LIST mxd_xia_dxp_record_function_list;
extern MX_MCA_FUNCTION_LIST mxd_xia_dxp_mca_function_list;

extern long mxd_xia_dxp_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_xia_dxp_rfield_def_ptr;

#endif /* __D_XIA_DXP_MCA_H__ */
