/*
 * Name:    mx_ccd.h
 *
 * Purpose: MX system header file for CCD camera systems.
 *
 * Author:  William Lavender
 *
 *----------------------------------------------------------------------------
 *
 * Copyright 2003 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MX_CCD_H__
#define __MX_CCD_H__

#include "mx_record.h"

#define MXU_CCD_HEADER_NAME_LENGTH	40

#define MXSF_CCD_ACQUIRING_FRAME	0x01
#define MXSF_CCD_READING_FRAME		0x02
#define MXSF_CCD_CORRECTING_FRAME	0x04
#define MXSF_CCD_WRITING_FRAME		0x08
#define MXSF_CCD_STOPPING		0x10

#define MXSF_CCD_ERROR			0x8000000

typedef struct {
	MX_RECORD *record;

	int data_frame_size[2];
	int bin_size[2];
	unsigned long status;

	int frame_type;
	int parameter_type;

	int start;
	int stop;
	int readout;
	int dezinger;
	int correct;
	int writefile;
	char writefile_name[MXU_FILENAME_LENGTH + 1];

	char header_variable_name[MXU_CCD_HEADER_NAME_LENGTH + 1];
	char header_variable_contents[MXU_BUFFER_LENGTH + 1];
} MX_CCD;

#define MXLV_CCD_DATA_FRAME_SIZE		17001
#define MXLV_CCD_BIN_SIZE			17002
#define MXLV_CCD_STATUS				17003
#define MXLV_CCD_START				17004
#define MXLV_CCD_STOP				17005
#define MXLV_CCD_READOUT			17006
#define MXLV_CCD_DEZINGER			17007
#define MXLV_CCD_CORRECT			17008
#define MXLV_CCD_WRITEFILE			17009
#define MXLV_CCD_WRITEFILE_NAME			17010
#define MXLV_CCD_HEADER_VARIABLE_NAME		17011
#define MXLV_CCD_HEADER_VARIABLE_CONTENTS	17012

#define MX_CCD_STANDARD_FIELDS \
  {MXLV_CCD_DATA_FRAME_SIZE, -1, "data_frame_size", MXFT_INT, NULL, 1, {2}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, data_frame_size), \
	{sizeof(int)}, NULL, 0 }, \
  \
  {MXLV_CCD_BIN_SIZE, -1, "bin_size", MXFT_INT, NULL, 1, {2}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, bin_size), \
	{sizeof(int)}, NULL, 0 }, \
  \
  {MXLV_CCD_STATUS, -1, "status", MXFT_HEX, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, status), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_START, -1, "start", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, start), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_STOP, -1, "stop", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, stop), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_READOUT, -1, "readout", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, readout), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_DEZINGER, -1, "dezinger", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, dezinger), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_CORRECT, -1, "correct", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, correct), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_WRITEFILE, -1, "writefile", MXFT_INT, NULL, 0, {0}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, writefile), \
	{0}, NULL, 0 }, \
  \
  {MXLV_CCD_WRITEFILE_NAME, -1, "writefile_name", \
	  		MXFT_STRING, NULL, 1, {MXU_FILENAME_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, writefile_name), \
	{sizeof(char)}, NULL, 0 }, \
  \
  {MXLV_CCD_HEADER_VARIABLE_NAME, -1, "header_variable_name", \
	  		MXFT_STRING, NULL, 1, {MXU_CCD_HEADER_NAME_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, header_variable_name), \
	{sizeof(char)}, NULL, 0 }, \
  \
  {MXLV_CCD_HEADER_VARIABLE_CONTENTS, -1, "header_variable_contents", \
	  		MXFT_STRING, NULL, 1, {MXU_BUFFER_LENGTH}, \
	MXF_REC_CLASS_STRUCT, offsetof(MX_CCD, header_variable_contents), \
	{sizeof(char)}, NULL, 0 }

typedef struct {
	mx_status_type ( *start ) ( MX_CCD *ccd );
	mx_status_type ( *stop ) ( MX_CCD *ccd );
	mx_status_type ( *get_status ) ( MX_CCD *ccd );
	mx_status_type ( *readout ) ( MX_CCD *ccd );
	mx_status_type ( *dezinger ) ( MX_CCD *ccd );
	mx_status_type ( *correct ) ( MX_CCD *ccd );
	mx_status_type ( *writefile ) ( MX_CCD *ccd );
	mx_status_type ( *get_parameter ) ( MX_CCD *ccd );
	mx_status_type ( *set_parameter ) ( MX_CCD *ccd );
} MX_CCD_FUNCTION_LIST;

MX_API_PRIVATE mx_status_type mx_ccd_get_pointers(
	MX_RECORD *ccd_record,
	MX_CCD **ccd,
	MX_CCD_FUNCTION_LIST **function_list_ptr,
	const char *calling_fname );

MX_API mx_status_type mx_ccd_start( MX_RECORD *record );

MX_API mx_status_type mx_ccd_stop( MX_RECORD *record );

MX_API mx_status_type mx_ccd_get_status( MX_RECORD *record,
					unsigned long *status );

MX_API mx_status_type mx_ccd_readout( MX_RECORD *record, int frame_type );

MX_API mx_status_type mx_ccd_dezinger( MX_RECORD *record, int frame_type );

MX_API mx_status_type mx_ccd_correct( MX_RECORD *record );

MX_API mx_status_type mx_ccd_writefile( MX_RECORD *record,
					char *filename,
					int frame_type );

MX_API mx_status_type mx_ccd_default_get_parameter_handler( MX_CCD *ccd );

MX_API mx_status_type mx_ccd_default_set_parameter_handler( MX_CCD *ccd );

MX_API mx_status_type mx_ccd_get_data_frame_size( MX_RECORD *record,
						int *x_size,
						int *y_size );

MX_API mx_status_type mx_ccd_get_bin_size( MX_RECORD *record,
						int *x_size,
						int *y_size );

MX_API mx_status_type mx_ccd_set_bin_size( MX_RECORD *record,
						int x_size,
						int y_size );

MX_API mx_status_type mx_ccd_write_header_variable( MX_RECORD *record,
						char *header_variable_name,
						char *header_variable_contents);

#endif /* __MX_CCD_H__ */
