/*
 * Name:    os_rtems_config.h
 *
 * Purpose: RTEMS specific parameters such as network configuration should
 *          be set here.  If you are not using RTEMS, then you do not need
 *          to do anything to this header file.
 *
 * Author:  William Lavender
 *
 *------------------------------------------------------------------------
 *
 * Copyright 2003 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __OS_RTEMS_CONFIG_H__
#define __OS_RTEMS_CONFIG_H__

/* Default network interface */

#ifdef RTEMS_BSP_NETWORK_DRIVER_NAME
#undef RTEMS_BSP_NETWORK_DRIVER_NAME
#endif

#ifdef RTEMS_BSP_NETWORK_DRIVER_ATTACH
#undef RTEMS_BSP_NETWORK_DRIVER_ATTACH
#endif

#define RTEMS_BSP_NETWORK_DRIVER_NAME	BSP_NE2000_NETWORK_DRIVER_NAME
#define RTEMS_BSP_NETWORK_DRIVER_ATTACH	BSP_NE2000_NETWORK_DRIVER_ATTACH

#define RTEMS_SET_ETHERNET_ADDRESS

#if defined( RTEMS_SET_ETHERNET_ADDRESS )
static char ethernet_address[6] = { 0xFE, 0xFD, 0x00, 0x00, 0x00, 0x01 };
#endif

static struct rtems_bsdnet_ifconfig netdriver_config = {
	RTEMS_BSP_NETWORK_DRIVER_NAME,		/* Name */
	RTEMS_BSP_NETWORK_DRIVER_ATTACH,	/* Attach function */

	NULL,			/* No next interface.  We only have one. */

#if defined( RTEMS_USE_BOOTP )
	NULL,			/* BOOTP supplies IP address. */
	NULL,			/* BOOTP supplies IP network mask. */
#else
	"192.168.238.100",	/* IP address. */
	"255.255.255.0",	/* IP network mask. */
#endif

#if defined( RTEMS_SET_ETHERNET_ADDRESS )
	ethernet_address,	/* Ethernet hardware address. */
#else
	NULL,			/* Driver supplies the hardware address. */
#endif
	0			/* Use default driver parameters. */
};

/* Network configuration */

struct rtems_bsdnet_config rtems_bsdnet_config = {
	&netdriver_config,

#if defined( RTEMS_USE_BOOTP )
	rtems_bsdnet_do_bootp,
#else
	NULL,
#endif

	0,			/* Default network task priority. */
	0,			/* Default mbuf capacity. */
	0,			/* Default mbuf cluster capacity. */

#if ! defined( RTEMS_USE_BOOTP )
	"mx",			/* Host name. */
	"localnet",		/* Domain name. */
#if 0
	"192.168.238.1",	/* Gateway. */
	"192.168.238.1",	/* Log host. */
	{ "192.168.238.1" },	/* Name server(s). */
	{ "192.168.238.1" },	/* NTP server(s). */
#endif
#endif

};

#define MX_RTEMS_TFTP_HOST_NAME	"mx"

#endif /* __OS_RTEMS_CONFIG_H__ */

